@@ -84,11 +84,12 @@ def covert_relationship_property(attr, attr_value):
             for item in attr_value:
                 info = dict()
                 for ar in attrs:
-                    new_attr_value = getattr(item, ar)
-                    if new_attr_value.__class__.__name__ not in ['RelationshipProperty', 'InstrumentedList']:
-                        info[ar] = new_attr_value
-                    else:
-                        info = covert_relationship_property(ar, new_attr_value)
+                    if hasattr(item, ar):
+                        new_attr_value = getattr(item, ar)
+                        if new_attr_value.__class__.__name__ not in ['RelationshipProperty', 'InstrumentedList']:
+                            info[ar] = new_attr_value
+                        else:
+                            info = covert_relationship_property(ar, new_attr_value)
                 if info:
                     new_data.append(info)
             return new_data
@@ -96,9 +97,10 @@ def covert_relationship_property(attr, attr_value):
             new_data = dict()
             for column, value in attr.entity.attrs.items():
                 if value.__class__.__name__ not in ['RelationshipProperty', 'InstrumentedList']:
-                    val = getattr(attr_value, column)
-                    if val.__class__.__name__ not in ['RelationshipProperty', 'InstrumentedList']:
-                        new_data[column] = val
+                    if hasattr(attr_value, column):
+                        val = getattr(attr_value, column)
+                        if val.__class__.__name__ not in ['RelationshipProperty', 'InstrumentedList']:
+                            new_data[column] = val
             return new_data
     else:
         return attr_value
@@ -112,10 +114,11 @@ def query_set_to_dict(obj):
             if hasattr(mapper, "attrs"):
                 attrs = mapper.attrs
                 for column, attr in attrs.items():
-                    attr_value = getattr(obj, column)
-                    value = covert_relationship_property(attr, attr_value)
-                    if not value.__class__.__name__ == 'RelationshipProperty':
-                        obj_dict[column] = value
+                    if hasattr(obj, column):
+                        attr_value = getattr(obj, column)
+                        value = covert_relationship_property(attr, attr_value)
+                        if not value.__class__.__name__ == 'RelationshipProperty':
+                            obj_dict[column] = value
 
             return obj_dict
         elif hasattr(obj, "keys"):
