@@ -118,8 +118,8 @@ def query_cache(cache_key, params=None, ex=3600 * 12, func=None, args=None, conn
 
 
 def request_interface(func, params, args, ex, cache_key):
-    # copy_params = copy.deepcopy(params)
-    data = func(*args, **params)
+    copy_params = copy.deepcopy(params)
+    data = func(*args, **copy_params)
     insert_cache(data, ex, cache_key)
 
 
