@@ -6,6 +6,7 @@ import os
 import platform
 import sys
 import traceback
+from types import FunctionType
 from typing import Optional
 
 import tornado.httpserver
@@ -40,6 +41,8 @@ define("eureka_config", default={}, type=dict, help="eureka配置")
 define("rms_register_enable", default=False, type=bool, help="是否启动资源注册")
 define("rms_register_server", default="http://127.0.0.1:8918", type=str, help="启动资源注册")
 define("operate_log_enable", default=False, type=bool, help="记录操作日志开关，默认关闭")
+define("operate_log_write_method", default="api", type=str, help="记录操作日志方式，默认是api")
+define("operate_log_write_func", default=None, type=FunctionType, help="记录操作的函数")
 define("write_operate_log_url", default="http://127.0.0.1:8918", type=str, help="记录操作日志接口")
 define("running_env", default="local", type=str, help="运行环境")
 define("request_type", default="request", type=str, help="请求类型")
@@ -67,6 +70,8 @@ define("url_log_enable", default=False, type=bool, help="项目url打印")
 define("cronjob_config", default={}, type=dict, help="定时任务配置")
 define("resource_register_enable", default=False, type=bool, help="资源注册开关")
 define("outside_screen_port", default=80, type=int, help="资源注册开关")
+define("custom_current_user_switch", default=False, type=bool, help="自定义用户开关")
+define("custom_current_user_func", default=None, type=FunctionType, help="自定义用户方法函数")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -226,7 +231,8 @@ class WebServer:
                 if isinstance(task, dict):
                     task_func = task.get("func")
                     task_kwargs = task.get("kwargs", {})
-                    if task_func:
+                    task_enable = task.get("enable", False)
+                    if task_enable:
                         options.scheduler.add_job(func=task_func, **task_kwargs)
         if options.cronjob_config:
             cronjob_config = options.cronjob_config
